import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AnalysisService } from '../service/analysis.service';
import {
  CDTO_analysis,
  CVO_analysis,
  FVO_analysis,
  QDTO_analysis,
  QVO_analysis,
  // UDTO_analysis,
  UVAO_analysis,
} from '../interface/analysis.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['查新检索'])
@Controller('/analysis')
export class AnalysisController extends BaseController {
  @Inject()
  service: AnalysisService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_analysis })
  async create(@Body() data: CDTO_analysis) {
    const dbData = await this.service.create(data);
    const result = new CVO_analysis(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_analysis })
  async query(
    @Query() filter: QDTO_analysis,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_analysis(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_analysis })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_analysis(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_analysis })
  async update(@Param('id') id: string, @Body() body: any) {
    const result = await this.service.update(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
