import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ApplyService } from '../service/apply.service';
import {
  CDTO_apply,
  CVO_apply,
  FVO_apply,
  QDTO_apply,
  QVO_apply,
  // UDTO_apply,
  UVAO_apply,
} from '../interface/apply.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['专利申请'])
@Controller('/apply')
export class ApplyController extends BaseController {
  @Inject()
  service: ApplyService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_apply })
  async create(@Body() data: CDTO_apply) {
    const dbData = await this.service.create(data);
    const result = new CVO_apply(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_apply })
  async query(
    @Query() filter: QDTO_apply,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_apply(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_apply })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_apply(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_apply })
  async update(@Param('id') id: string, @Body() body: any) {
    const result = await this.service.update(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
