import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AssessmentService } from '../service/assessment.service';
import {
  CDTO_assessment,
  CVO_assessment,
  FVO_assessment,
  QDTO_assessment,
  QVO_assessment,
  // UDTO_assessment,
  UVAO_assessment,
} from '../interface/assessment.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['价值评估'])
@Controller('/assessment')
export class AssessmentController extends BaseController {
  @Inject()
  service: AssessmentService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_assessment })
  async create(@Body() data: CDTO_assessment) {
    const dbData = await this.service.create(data);
    const result = new CVO_assessment(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_assessment })
  async query(
    @Query() filter: QDTO_assessment,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_assessment(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_assessment })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_assessment(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_assessment })
  async update(@Param('id') id: string, @Body() body: any) {
    const result = await this.service.update(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
