import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ExamNoticeService } from '../service/examNotice.service';
import {
  CDTO_examNotice,
  CVO_examNotice,
  FVO_examNotice,
  QDTO_examNotice,
  QVO_examNotice,
  UDTO_examNotice,
  UVAO_examNotice,
} from '../interface/examNotice.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['审核通知消息表'])
@Controller('/examNotice')
export class ExamNoticeController extends BaseController {
  @Inject()
  service: ExamNoticeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_examNotice })
  async create(@Body() data: CDTO_examNotice) {
    const dbData = await this.service.create(data);
    const result = new CVO_examNotice(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_examNotice })
  async query(
    @Query() filter: QDTO_examNotice,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_examNotice(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_examNotice })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_examNotice(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_examNotice })
  async update(@Param('id') id: string, @Body() body: UDTO_examNotice) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
