import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PatentWarningService } from '../service/patentWarning.service';
import {
  CDTO_patentWarning,
  CVO_patentWarning,
  FVO_patentWarning,
  QDTO_patentWarning,
  QVO_patentWarning,
  UDTO_patentWarning,
  UVAO_patentWarning,
} from '../interface/patentWarning.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['专利预警消息表'])
@Controller('/patentWarning')
export class PatentWarningController extends BaseController {
  @Inject()
  service: PatentWarningService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_patentWarning })
  async create(@Body() data: CDTO_patentWarning) {
    const dbData = await this.service.create(data);
    const result = new CVO_patentWarning(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_patentWarning })
  async query(
    @Query() filter: QDTO_patentWarning,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_patentWarning(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_patentWarning })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_patentWarning(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_patentWarning })
  async update(@Param('id') id: string, @Body() body: UDTO_patentWarning) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
