import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SafegService } from '../service/safeg.service';
import {
  CDTO_safeg,
  CVO_safeg,
  FVO_safeg,
  QDTO_safeg,
  QVO_safeg,
  // UDTO_safeg,
  UVAO_safeg,
} from '../interface/safeg.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['专利维权'])
@Controller('/safeg')
export class SafegController extends BaseController {
  @Inject()
  service: SafegService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_safeg })
  async create(@Body() data: CDTO_safeg) {
    const dbData = await this.service.create(data);
    const result = new CVO_safeg(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_safeg })
  async query(
    @Query() filter: QDTO_safeg,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_safeg(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_safeg })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_safeg(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_safeg })
  async update(@Param('id') id: string, @Body() body: any) {
    const result = await this.service.update(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
