import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TecholService } from '../service/techol.service';
import {
  CDTO_techol,
  CVO_techol,
  FVO_techol,
  QDTO_techol,
  QVO_techol,
  UDTO_techol,
  UVAO_techol,
} from '../interface/techol.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['专利需求'])
@Controller('/techol')
export class TecholController extends BaseController {
  @Inject()
  service: TecholService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_techol })
  async create(@Body() data: CDTO_techol) {
    const dbData = await this.service.create(data);
    const result = new CVO_techol(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_techol })
  async query(
    @Query() filter: QDTO_techol,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_techol(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_techol })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_techol(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_techol })
  async update(@Param('id') id: string, @Body() body: UDTO_techol) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
