import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TranstionService } from '../service/transtion.service';
import {
  CDTO_transtion,
  CVO_transtion,
  FVO_transtion,
  QDTO_transtion,
  QVO_transtion,
  UDTO_transtion,
  UVAO_transtion,
} from '../interface/transtion.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['专利交易'])
@Controller('/transtion')
export class TranstionController extends BaseController {
  @Inject()
  service: TranstionService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_transtion })
  async create(@Body() data: CDTO_transtion) {
    const dbData = await this.service.create(data);
    const result = new CVO_transtion(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_transtion })
  async query(
    @Query() filter: QDTO_transtion,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_transtion(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_transtion })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_transtion(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_transtion })
  async update(@Param('id') id: string, @Body() body: UDTO_transtion) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
